@@ -34,7 +34,7 @@ class BaseService:
 
         return value_id
 
-    def _sync_many_with_redis(self, sql):
+    def _sync_many_with_redis(self, sql, attrs_id=None):
         results = self.__execute_sql(sql, many=True)
 
         if not results:
@@ -44,7 +44,13 @@ class BaseService:
 
         for result in results:
             value_id, json = self._entity.__to_json__(values=result)
-            self.__save_redis(value_id, json)
+
+            if attrs_id and isinstance(attrs_id, list):
+                self.__attributes_to_id(attrs_id, json)
+
+            else:
+                self.__save_redis(value_id, json)
+
             list_ids.append(value_id)
 
         return list_ids
@@ -52,6 +58,19 @@ class BaseService:
     def __save_redis(self, value_id, payload):
         self._redis.add(collection=self._name, key=value_id, value=payload)
 
+    def __attributes_to_id(self, attrs_id, json):
+        _id = ''
+        for attr in attrs_id:
+            if not _id:
+                _id = json.get(attr)
+
+            else:
+                _id = f'{_id}_{json.get(attr)}'
+
+        self.__save_redis(_id, json)
+
+        return _id
+
     def _get_sql(self): ...
 
     def sync(self): ...
